==> gpte-0.0.1-py3-none-any.whl: gpte/gpte.py <==
import argparse
import logging
import sys

import openai

import gpte


def args_init():
    parser = argparse.ArgumentParser(description="Translate everything to English")

    parser.add_argument(
        "text",
        help="text",
        type=str,
        nargs="*",
    )
    parser.add_argument("--key", dest="key", help="set api key")
    parser.add_argument("-f", "--file", dest="file", help="read from file")
    parser.add_argument(
        "-t",
        "--translate",
        dest="translate",
        action="store_true",
        default=True,
        help="translate something to English",
    )
    parser.add_argument(
        "-c",
        "--chinese",
        dest="chinese",
        action="store_true",
        default=False,
        help="translate something to Chinese",
    )
    parser.add_argument(
        "-a",
        "--ask",
        dest="ask",
        action="store_true",
        default=False,
        help="ask ChatGPT",
    )
    parser.add_argument(
        "-p",
        "--polish",
        dest="polish",
        action="store_true",
        default=False,
        help="polish something",
    )
    parser.add_argument(
        "-d",
        "--debug",
        dest="debug",
        action="store_true",
        default=False,
        help="enable debug output",
    )
    parser.add_argument(
        "-v",
        "--version",
        action="version",
        version="%(prog)s " + gpte.__version__,
    )
    try:
        return parser.parse_args()
    except Exception:
        sys.exit(0)


def init_logging(debug: bool):
    level = logging.INFO
    if debug:
        level = logging.DEBUG
    logging.basicConfig(
        level=level,
        stream=sys.stdout,
        format="%(asctime)s - %(levelname)s - %(message)s",
    )


key_file = "/tmp/gpte-key.txt"


def set_apikey(key):
    with open(key_file, "w") as f:
        f.write(key)


def get_apikey():
    with open(key_file) as f:
        openai.api_key = f.readline().strip()


def ask_gpt(text):
    completion = openai.ChatCompletion.create(
        model="gpt-3.5-turbo",
        messages=[{"role": "user", "content": text}],
        temperature=0.2,
    )
    return str(completion.choices[0].message.content).removeprefix("\n\n").strip()


def ask_gpt_with(pre, text):
    return ask_gpt(f'{pre}\n"{text}"')


def translate(text):

    msg = "Please translate the following text into English, and polish it to make it sound more natural and in line with native speaker conventions. Please refrain from providing any additional output beyond the translated text"
    return ask_gpt_with(msg, text)


def polishing(text):
    msg = "Please polish my following text, output language according to the original language"
    return ask_gpt_with(msg, text)


def chinese(text):
    msg = "Please translate the following text into Chinese, and polish it to make it sound more natural and in line with native speaker conventions. Please refrain from providing any additional output beyond the translated text"
    return ask_gpt_with(msg, text)


def main():
    args = args_init()
    init_logging(args.debug)

    if args.key:
        logging.debug("key mode")
        set_apikey(args.key)
        exit(0)

    try:
        get_apikey()
    except Exception:
        print("please run tt --key sk-... first")
        exit(0)

    text = " ".join(args.text)
    if args.file:
        with open(args.file) as f:
            text = "\n".join(f.readlines())
    if not text:
        print("Please enter some content")
        exit(0)

    if args.ask:
        logging.debug("ask mode")
        print(ask_gpt(text))
    elif args.polish:
        logging.debug("polish mode")
        print(polishing(text))
    elif args.chinese:
        logging.debug("chinese mode")
        print(chinese(text))
    else:
        logging.debug("translate mode")
        print(translate(text))

==> gpte-0.0.4-py3-none-any.whl: gpte/gpte.py <==
import argparse
import logging
import sys

import openai

import gpte


def args_init():
    parser = argparse.ArgumentParser(description="Translate everything to English")

    parser.add_argument(
        "text",
        help="text",
        type=str,
        nargs="*",
    )
    parser.add_argument("--key", dest="key", help="set api key")
    parser.add_argument("-f", "--file", dest="file", help="read from file")
    parser.add_argument(
        "-t",
        "--translate",
        dest="translate",
        action="store_true",
        default=True,
        help="translate something to English",
    )
    parser.add_argument(
        "-c",
        "--chinese",
        dest="chinese",
        action="store_true",
        default=False,
        help="translate something to Chinese",
    )
    parser.add_argument(
        "-a",
        "--ask",
        dest="ask",
        action="store_true",
        default=False,
        help="ask ChatGPT",
    )
    parser.add_argument(
        "-p",
        "--polish",
        dest="polish",
        action="store_true",
        default=False,
        help="polish something",
    )
    parser.add_argument(
        "-d",
        "--debug",
        dest="debug",
        action="store_true",
        default=False,
        help="enable debug output",
    )
    parser.add_argument(
        "-v",
        "--version",
        action="version",
        version="%(prog)s " + gpte.__version__,
    )
    try:
        return parser.parse_args()
    except Exception:
        sys.exit(0)


def init_logging(debug: bool):
    level = logging.INFO
    if debug:
        level = logging.DEBUG
    logging.basicConfig(
        level=level,
        stream=sys.stdout,
        format="%(asctime)s - %(levelname)s - %(message)s",
    )


key_file = "/tmp/gpte-key.txt"


def set_apikey(key):
    with open(key_file, "w") as f:
        f.write(key)


def get_apikey():
    with open(key_file) as f:
        openai.api_key = f.readline().strip()


def ask_gpt(text):
    completion = openai.ChatCompletion.create(
        model="gpt-3.5-turbo",
        messages=[{"role": "user", "content": text}],
        temperature=0.2,
    )
    return str(completion.choices[0].message.content).strip()


def ask_gpt_with(pre, text):
    return ask_gpt(f'{pre}\n"{text}"')


def translate(text):

    msg = "Please translate the following text into English, and polish it to make it sound more natural and in line with native speaker conventions. Please refrain from providing any additional output beyond the translated text"
    return ask_gpt_with(msg, text)


def polishing(text):
    msg = "Please polish my following text, output language according to the original language"
    return ask_gpt_with(msg, text)


def chinese(text):
    msg = "Please translate the following text into Chinese, and polish it to make it sound more natural and in line with native speaker conventions. Please refrain from providing any additional output beyond the translated text"
    return ask_gpt_with(msg, text)


def main():
    args = args_init()
    init_logging(args.debug)

    if args.key:
        logging.debug("key mode")
        set_apikey(args.key)
        exit(0)

    try:
        get_apikey()
    except Exception:
        print("please run ee --key sk-... first")
        exit(0)

    text = " ".join(args.text)
    if args.file:
        with open(args.file) as f:
            text = "\n".join(f.readlines())
    if not text:
        print("Please enter some content")
        exit(0)

    if args.ask:
        logging.debug("ask mode")
        print(ask_gpt(text))
    elif args.polish:
        logging.debug("polish mode")
        print(polishing(text))
    elif args.chinese:
        logging.debug("chinese mode")
        print(chinese(text))
    else:
        logging.debug("translate mode")
        print(translate(text))
